@@ -2,17 +2,16 @@
 import re
 import os
 from lib.parsing import DfxParser
-from lib.register_rout import Rout
 from lib.state import RegOperation
 from lib.dump import Dump
 
 
 class Executor(object):
 
-    def __init__(self, rout="rdma"):
+    def __init__(self, rout):
         self.parser = DfxParser()
         self.log_dump = None
-        self.rout = Rout(rout)
+        self.rout = rout
         self.variable_list = list()
         self.dfx_folder = os.path.join(os.path.dirname(__file__), "..", "configuration")
 
@@ -21,12 +20,22 @@ class Executor(object):
         if full_path is not None:
             self.log_dump = Dump()
             parse_dict = self.parser.run(full_path)
+            self.print_coms(parse_dict["com"])
             self.read_and_write_reg(parse_dict["var"])
             self.check_expected(parse_dict["exp"])
-        pass
+
+    def print_coms(self, coms):
+        self.log_dump.log("[COM]\n")
+        self.log_dump.dump_com("Name", "Register", "Index", "Value")
+        for item in coms:
+            for index in range(int(item[2])):
+                reg_addr = int(item[1], 16)
+                reg_addr = reg_addr + index*4
+                value = self.rout.read_uint32(reg_addr)
+                self.log_dump.dump_com(item[0], "{:#x}".format(reg_addr), str(index), "{:#x}".format(value))
 
     def check_expected(self, expressions):
-        self.log_dump.log("\n\n###################################begin to check expression##########\n\n")
+        self.log_dump.log("\n[EXP]\n")
         for expression in expressions:
             if expression["equation"] is not None:
                 if self.calc_expression(expression["equation"]):
@@ -44,9 +53,9 @@ class Executor(object):
             if expression_string is not None:
                 result, convert_exp = self.calc_expression(expression_string)
                 if result:
-                    self.log_dump.log("Pass      {} => {}    {}\n".format(expression_string, convert_exp, expression_info))
+                    self.log_dump.log("Pass   {}   {} => {}\n".format(expression_info, expression_string, convert_exp))
                 else:
-                    self.log_dump.log("Fail      {} => {}    {}\n".format(expression_string, convert_exp, expression_info))
+                    self.log_dump.log("Fail   {}   {} => {}\n".format(expression_info, expression_string, convert_exp))
 
     def calc_expression(self, expression):
         convert_exp = expression
@@ -60,20 +69,21 @@ class Executor(object):
             result = False
         return result, convert_exp
 
-    def list(self):
-        all_files = os.listdir(self.dfx_folder)
-        for item in all_files:
-            if "dfx" in item:
-                print(item)
-
     def get_full_path(self, dfx_file):
-        full_path = os.path.join(self.dfx_folder, dfx_file)
-        if os.path.exists(full_path) is False:
-            print("{} not exist".format(dfx_file))
-            full_path = None
+        if os.path.exists(dfx_file) is False:
+            full_path = os.path.join(self.dfx_folder, dfx_file)
+            if os.path.exists(full_path) is False:
+                full_path = os.path.join(os.getcwd(), dfx_file)
+                if os.path.exists(full_path) is False:
+                    print("{} not exist".format(dfx_file))
+                    full_path = None
+        else:
+            full_path = dfx_file
         return full_path
 
     def read_and_write_reg(self, vars):
+        self.log_dump.log("\n[var]\n")
+        self.log_dump.dump("Name", "Operation", "Value", "Expression")
         for var in vars:
             if var["type"] == RegOperation.write:
                 self.write_reg(var["reg_address"], var["value"])
@@ -125,27 +135,16 @@ class Executor(object):
         if rets:
             reg_addr = int(rets[0][0], 16)
             reg_range = rets[0][1]
-            orgi_value = self.rout.read(reg_addr)
-            # import random
-            # orgi_value = random.randrange(10, 10000)
+            orgi_value = self.rout.read_uint32(reg_addr)
             value = self.get_value_with_range(orgi_value, reg_range)
         return value
 
     def write_reg(self, offset, value):
         get_value = eval(self.get_expression_var(value))
         offset = int(offset, 16)
-        self.rout.write(offset, get_value)
+        self.rout.write_uint32(offset, get_value)
         self.log_dump.dump(operation="write", value=get_value, expression="Register 0x{:x}".format(offset))
 
-    # def read_reg(self, variable):
-    #     addr = int(variable["reg_address"], 16)
-    #     # orgi_value = self.rout.read(addr)
-    #     orgi_value = 0x1b1b
-    #     value = self.get_value_with_range(orgi_value, variable["range"])
-    #     self.log_dump.dump(name=variable["name"], operation="read", register=variable["reg_address"],
-    #                        range_=variable["range"], original_value=orgi_value, value=value)
-    #     return value
-
     @staticmethod
     def get_value_with_range(value, bit_range):
         value_ = None
